@@ -11,7 +11,7 @@ from easygui import *
 os.environ['COLOREDLOGS_LOG_FORMAT'] = '%(asctime)s [%(levelname)s] %(message)s'
 os.environ['COLOREDLOGS_DATE_FORMAT'] = '%H:%M:%S'
 os.environ['COLOREDLOGS_FIELD_STYLES'] = 'levelname=15; asctime=14'
-os.environ['COLOREDLOGS_LEVEL_STYLES'] = 'info=35;debug=28;warning=202;error=124;error=background=red'
+os.environ['COLOREDLOGS_LEVEL_STYLES'] = 'info=35;debug=28;warning=202;error=14;error=background=red'
 # Create a logger object.
 logger = logging.getLogger(__name__)
 
@@ -80,7 +80,7 @@ def generate_project_folder(root_directory, project_name=None, user_template=Non
         copy_template(templates_dir, user_template, destination_directory)
     else:
         logger.error(f"Selected template not available.")
-        logger.info("Here are the template available.")
+        logger.info("Here are the templates available.")
         print(available_templates)
         exit(1)
 
